@@ -8,7 +8,7 @@ logger.info("Test Starts")
 def test_run_without_exception():
     err_msg = "Something went wrong. Report immediately."
 
-    with Browser(name="Chrome", implicit_wait=10, headless=True) as browser:
+    with Browser(name="Chrome", implicit_wait=10, headless=False) as browser:
         logger.info("Test Starts")
         google = browser.open("https://google.com")
         yahoo = browser.open("https://yahoo.com")
